@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2014 GNS3 Technologies Inc.
+# Copyright (C) 2023 GNS3 Technologies Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,19 +15,35 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import sys
+import atexit
+import logging
 import os
-import pkg_resources
+import sys
+
+try:
+    import importlib_resources
+except ImportError:
+    from importlib import resources as importlib_resources
+
+
+from contextlib import ExitStack
+resource_manager = ExitStack()
+atexit.register(resource_manager.close)
+
+log = logging.getLogger(__name__)
 
 
 def get_resource(resource_name):
+    """
+    Return a resource in current directory or in frozen package
+    """
 
     resource_path = None
-    if hasattr(sys, "frozen") and sys.platform.startswith("darwin"):
-        resource_name = os.path.join("../Resources", resource_name)
-    if hasattr(sys, "frozen") and os.path.exists(resource_name):
-        resource_path = os.path.normpath(os.path.join(os.getcwd(), resource_name))
-    elif not hasattr(sys, "frozen") and pkg_resources.resource_exists("gns3", resource_name):
-        resource_path = pkg_resources.resource_filename("gns3", resource_name)
-        resource_path = os.path.normpath(resource_path)
+    if hasattr(sys, "frozen"):
+        resource_path = os.path.normpath(os.path.join(os.path.dirname(sys.executable), resource_name))
+    else:
+        ref = importlib_resources.files("gns3") / resource_name
+        path = resource_manager.enter_context(importlib_resources.as_file(ref))
+        if os.path.exists(path):
+            resource_path = os.path.normpath(path)
     return resource_path
